@@ -21,7 +21,7 @@ if 'phonostats' in settings.INSTALLED_APPS:
     from phonostats.utils import getNeighCount,getPhonotacticProb
 
 if 'celex' in settings.INSTALLED_APPS:
-    from celex.utils import lookupFreq,lookupCat
+    from celex.utils import lookupFreq,lookupCat,categorize_words
 
 from .helper import fetch_buckeye_resource,reorganize
 from .managers import BulkManager
@@ -559,9 +559,15 @@ class WordToken(models.Model):
             prev_context = self.getPreviousContext(window = int(window))
         else:
             prev_context = self.getPreviousContext()
-        context = ['#'.join([str(x),lookupCat(str(x))]) for x in prev_context if lookupCat(str(x)) in ['n','v','a','r'] and str(x) != str(self)]
-        cat =lookupCat(str(self))
-        if cat == 'NA':
+        catted = categorize_words([str(x)
+                                for x in prev_context
+                                    if str(x) != str(self)]
+                                + [str(self)])
+        cat_word = catted.pop(-1)
+        tagged_context = [x for x in
+                            catted
+                            if x[-2] == '#' and x[-1] in ['n','v','a','r']]
+        if cat_word.endswith('NA'):
             cat = self.Category.Label
             if 'N' in cat:
                 cat = 'n'
@@ -573,7 +579,8 @@ class WordToken(models.Model):
                 cat = 'r'
             else:
                 cat = 'NA'
-        sp = getSemanticRelatedness('#'.join([self.WordType.Label,cat]),context,style=style)
+            cat_word  = '#'.join([cat_word.split("#")[0],cat])
+        sp = getSemanticRelatedness(cat_word,tagged_context,style=style)
         if style == 'A' and window == 'A':
             self.PrevSemPred = sp
             self.save()
@@ -588,9 +595,15 @@ class WordToken(models.Model):
             foll_context = self.getFollowingContext(window = int(window))
         else:
             foll_context = self.getFollowingContext()
-        context = ['#'.join([str(x),lookupCat(str(x))]) for x in foll_context if lookupCat(str(x)) in ['n','v','a','r'] and str(x) != str(self)]
-        cat =lookupCat(str(self))
-        if cat == 'NA':
+        catted = categorize_words([str(x)
+                                for x in foll_context
+                                    if str(x) != str(self)]
+                                + [str(self)])
+        cat_word = catted.pop(-1)
+        tagged_context = [x for x in
+                            catted
+                            if x[-2] == '#' and x[-1] in ['n','v','a','r']]
+        if cat_word.endswith('NA'):
             cat = self.Category.Label
             if 'N' in cat:
                 cat = 'n'
@@ -602,7 +615,8 @@ class WordToken(models.Model):
                 cat = 'r'
             else:
                 cat = 'NA'
-        sp = getSemanticRelatedness('#'.join([self.WordType.Label,cat]),context,style=style)
+            cat_word  = '#'.join([cat_word.split("#")[0],cat])
+        sp = getSemanticRelatedness(cat_word,tagged_context,style=style)
         if style == 'A' and window == 'A':
             self.FollSemPred = sp
             self.save()
